# Pupa: A legislative data scraping framework

[![Build Status](https://travis-ci.com/opencivicdata/pupa.svg?branch=master)](https://travis-ci.com/opencivicdata/pupa)
[![Coverage Status](https://coveralls.io/repos/opencivicdata/pupa/badge.png?branch=master)](https://coveralls.io/r/opencivicdata/pupa?branch=master)
[![PyPI](https://img.shields.io/pypi/v/pupa.svg)](https://pypi.python.org/pypi/pupa)
